#!/usr/bin/env node

const { execSync } = require("child_process");

const runCommand = (command) => {
  try {
    execSync(`${command}`, { stdio: "inherit" });
  } catch (error) {
    console.error(`Failed to execute ${command}`, error);
    return false;
  }
  return true;
};

if (process.argv.length < 3) {
  console.log("ERR! please provide a name for your project.");
  console.log("For example: $ npx create-bash-boilerplate <my-project-name>");
  process.exit(1);
}

const repoName = process.argv[2];

const gitCheckoutCommand = `git clone --depth 1 https://github.com/SegopotsoMakhutja/create-bash-quickstart.git ${repoName}`;
const installDepsCommand = `cd ${repoName} && npm install`;
const initGitCommand = `cd ${repoName} && npx rimraf ./.git && git init`;

console.log(`Cloning the repo into the project: ${repoName}`);

const checkedOut = runCommand(gitCheckoutCommand);
if (!checkedOut) process.exit(-1);

console.log("Installing project dependencies");

const installedDeps = runCommand(installDepsCommand);
if (!installedDeps) process.exit(-1);

console.log("initializing git for project");
runCommand(initGitCommand);

console.log("🚀 Congratulations, project has been setup successfully.");
console.log("Follow the commands below to start the app in development mode.");
console.log(`cd ${repoName} && npm run dev`);
